sync

package
v0.8.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 28, 2020 License: AGPL-3.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Receive

func Receive(stored *file.Data, ReorderExercises chan bool, FirstExercise chan string, key *[]byte, code, username string) error

Receive starts the retrieving process for fetching a shared file.

func StartSync

func StartSync(synccode chan string, username string, key *[]byte) error

StartSync starts up the server on the local network and returns it so we can call shutdown.

Types

This section is empty.

Jump to